==> dde-network-core_1.0.69.orig.tar.xz: dde-network-core-1.0.69/dss-network-plugin/translations/dss-network-plugin_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="gl_ES" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 nova mensaxe</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 conectado</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Conexión con fíos</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Punto de acceso</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocolo</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipo de seguranza</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canle</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de rede</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pasarela</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primario</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefixo</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidade</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo desactivado</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectado pero sen acceso a internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Sen conexión</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cabo de rede desconectado</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autenticando</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obtendo o enderezo IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Conectado</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Desconectado</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Con erros</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Rede con fíos</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rede con fíos % 1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rede sen fíos</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rede sen fíos %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo desactivado</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cabo de rede desconectado</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Sen conexión</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectado pero sen acceso a internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Desactivar a conexión con fíos</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Activa a conexión con fíos</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Desactivar a conexión sen fíos</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Activar a conexión sen fíos</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Desactivar a rede</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Activar a rede</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Axustes da rede</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.2.orig.tar.xz: dde-network-core-1.1.2/dss-network-plugin/translations/dss-network-plugin_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="gl_ES">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 nova mensaxe</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Rede sen fíos</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rede con fíos</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 conectado</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Conectar a unha rede oculta</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasinal</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Punto de acceso</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocolo</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipo de seguranza</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canle</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de rede</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Pasarela</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primario</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefixo</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidade</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo desactivado</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectado pero sen acceso a internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Sen conexión</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cabo de rede desconectado</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autenticando</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obtendo o enderezo IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Conectado</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Desconectado</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Con erros</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Rede con fíos</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rede con fíos % 1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rede sen fíos</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rede sen fíos %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo desactivado</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cabo de rede desconectado</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Sen conexión</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectado pero sen acceso a internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Desactivar a conexión con fíos</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Activa a conexión con fíos</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Desactivar a conexión sen fíos</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Activar a conexión sen fíos</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Desactivar a rede</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Activar a rede</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Axustes da rede</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Conexión con fíos</translation>
    </message>
</context>
</TS>
